@@ -1,22 +1,13 @@
-//  
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//
+//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
-#ifdef HAVE_IOSTREAM
+
 #include <iostream>
-#else
-#include <iostream.h>
-#endif
 #include "general.h"
 #include "llist.h"
 
-CVSID("$Id$");
-CVSID_DOT_H(LLIST_H_CVSID);
-
 LList::LNode::LNode( void *data ){
   data_ = data;
   next_ = NULL;
@@ -65,7 +56,7 @@ int LList::push( void *data ){
 
 void *LList::pop( void ){
   void *temp;
-  struct LNode *temp2;
+  LNode *temp2;
 
   if ( !n_ ) return ( NULL );
 
@@ -88,7 +79,7 @@ void *LList::pop( void ){
 
 void *LList::dequeue( void ){
   void *temp;
-  struct LNode *temp2;
+  LNode *temp2;
 
   if ( !n_ ) return ( NULL );
 
